@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
 from .payment_term import *
@@ -12,6 +12,9 @@ def register():
     Pool.register(
         PaymentTerm,
         PaymentTermLine,
+        PaymentTermLineRelativeDelta,
+        TestPaymentTermView,
+        TestPaymentTermViewResult,
         Invoice,
         InvoicePaymentLine,
         InvoiceLine,
@@ -31,6 +34,7 @@ def register():
         ConfigurationTaxRounding,
         module='account_invoice', type_='model')
     Pool.register(
+        TestPaymentTerm,
         PrintInvoice,
         PayInvoice,
         CreditInvoice,
